Mm

Struct Mm 

#[repr(align(64))]
pub struct Mm { hhdm_offset: AtomicU64, pmm: UncheckedCell<IrqMutex<Pmm>>, kernel_addr_space: UncheckedCell<IrqMutex<AddressSpace>>, next_kernel_stack: AtomicU64, }
Holds memory management state such as slab allocators and virtual memory areas

Fields

hhdm_offset: AtomicU64pmm: UncheckedCell<IrqMutex<Pmm>>kernel_addr_space: UncheckedCell<IrqMutex<AddressSpace>>next_kernel_stack: AtomicU64

Implementations

Source

impl Mm

pub const fn new() -> Self

Constructor; initializes all values zeroed or uninited

pub fn init(&self)

Initialize Mm’s default values

pub fn set_hhdm_offset(&self, offset: u64)

Sets the HHDM offset

pub unsafe fn init_pmm(&self, pmm: Pmm)

Move the given Pmm into Mm::pmm

Safety

The caller must guarantee the following:

  • That this method has never been called before and will never be called again
  • That at the time of calling this method, no references or pointers to this data exist
  • While this method is being called, no other CPU is working with the given data
pub unsafe fn init_kernel_addr_space(&self, kernel_addr_space: AddressSpace)

Move the given AddressSpace into Mm::kernel_addr_space

Safety

The caller must guarantee the following:

  • That this method has never been called before and will never be called again
  • That at the time of calling this method, no references or pointers to this data exist
  • While this method is being called, no other CPU is working with the given data
pub fn hhdm_offset(&self) -> u64

Getter for the hhdm offset

pub unsafe fn pmm(&self) -> &IrqMutex<Pmm>

Getter for Mm::pmm

Safety

The caller must guarantee the following:

  • That this value’s init method has already been called before
  • That at this method’s entire execution time, no mutable references or pointers to this data exist or will exist
pub unsafe fn kernel_addr_space(&self) -> &IrqMutex<AddressSpace>

Getter for Mm::kernel_address_space

Safety

The caller must guarantee the following:

  • That this value’s init method has already been called before
  • That at this method’s entire execution time, no mutable references or pointers to this data exist or will exist
pub fn alloc_kernel_stack_slot(&self) -> VirtAddr

Get the starting address of the next kernel stack and increment it